._tree_1b5hq_2{width:280px;overflow:auto;border-radius:0;padding-right:1rem;border-right:1px solid #d9d9d9;--indent-size: 12px;--node-width: 36px;--node-height: 36px}._tree_1b5hq_2 .ant-tree-node-content-wrapper{min-height:var(--node-height)!important;line-height:var(--node-height)!important;padding-inline:0!important;display:flex}._tree_1b5hq_2 .ant-tree-iconEle{width:var(--node-width)!important;height:var(--node-height)!important;display:flex!important;align-items:center!important;justify-content:center!important}._tree_1b5hq_2 .ant-tree-treenode{min-width:100%;width:fit-content}._tree_1b5hq_2 .ant-tree-title{padding-right:1rem}._tree_1b5hq_2 .ant-tree-node-content-wrapper.ant-tree-node-selected{color:inherit!important}._tree_1b5hq_2 .ant-tree-switcher{display:flex;justify-content:center;align-items:center}._tree_1b5hq_2 .ant-tree-switcher:before{height:var(--node-height)!important;line-height:var(--node-height)!important}._tree_1b5hq_2 .ant-tree-switcher-icon{font-size:12px!important;color:#b3b6bd!important}._list_1klmh_1 .ant-list-header+div{flex:1 1 auto;overflow-y:auto;min-height:0px}._shortcutPathDropdown_1klmh_7 .ant-dropdown-menu .ant-dropdown-menu-item:hover{background-color:#eff6ff!important;color:#3b82f6!important}._listItem_1klmh_14:hover{background-color:#eff4ff}._listItem_1klmh_14:first-child:hover{border-top-left-radius:.5rem;border-top-right-radius:.5rem}._listItem_1klmh_14:last-child:hover{border-bottom-left-radius:.5rem;border-bottom-right-radius:.5rem}
